:github_url:

.. _support:

Getting Help
============

There are multiple ways of getting help.

.. _bugs:

Reporting Bugs & Issues
-----------------------

Bugs and any kind of issues should be reported in the project's `Github issue tracker`_. This is also a good place to ask questions about *scherbelberg*.

.. _Github issue tracker: https://github.com/pleiszenburg/scherbelberg/issues

Paid Support
------------

In addition to the previous options, paid support is available from `pleiszenburg.de - Independent Scientific Services`_.

.. _pleiszenburg.de - Independent Scientific Services: http://www.pleiszenburg.de
